Documentation
¶
Index ¶
- Constants
- type Error
- func (e *Error) Code() string
- func (e *Error) Error() string
- func (e *Error) GetCode() (value string, ok bool)
- func (e *Error) GetHREF() (value string, ok bool)
- func (e *Error) GetID() (value string, ok bool)
- func (e *Error) GetReason() (value string, ok bool)
- func (e *Error) HREF() string
- func (e *Error) ID() string
- func (e *Error) Kind() string
- func (e *Error) Reason() string
Constants ¶
const ErrorKind = "Error"
Error kind is the name of the type used to represent errors.
const ErrorNilKind = "ErrorNil"
ErrorNilKind is the name of the type used to nil errors.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Error ¶
type Error struct {
// contains filtered or unexported fields
}
Error represents errors.
func UnmarshalError ¶
UnmarshalError reads an error from the given which can be an slice of bytes, a string, a reader or a JSON decoder.
func (*Error) GetCode ¶
GetCode returns the link of the error and a flag indicating if the code has a value.
func (*Error) GetHREF ¶
GetHREF returns the link of the error and a flag indicating if the link has a value.
func (*Error) GetID ¶
GetID returns the identifier of the error and a flag indicating if the identifier has a value.
Click to show internal directories.
Click to hide internal directories.